@@ -11,7 +11,12 @@ from selenium.webdriver import ActionChains  # noqa
 from selenium.webdriver import FirefoxOptions  # noqa
 from selenium.webdriver import FirefoxProfile  # noqa
 from selenium.webdriver import Proxy  # noqa
-from selenium.webdriver import TouchActions  # noqa
+
+try:
+    # TouchActions does not exist in Selenium 4.1.1
+    from selenium.webdriver import TouchActions  # noqa
+except ImportError:
+    pass
 from selenium.webdriver import Chrome as _Chrome
 from selenium.webdriver import ChromeOptions, DesiredCapabilities
 from selenium.webdriver import Edge as _Edge
@@ -26,7 +31,7 @@ SELENIUM_V4 = parse_version(getattr(selenium, '__version__', '0')) >= parse_vers
 
 
 class DriverCommonMixin:
-    """Operations common to all webdriver types."""
+    """Attributes common to all webdriver types."""
 
     def _setup_backend(self, seleniumwire_options: Dict[str, Any]) -> Dict[str, Any]:
         """Create the backend proxy server and return its configuration
@@ -121,7 +126,7 @@ class DriverCommonMixin:
 
 
 class Firefox(InspectRequestsMixin, DriverCommonMixin, _Firefox):
-    """Extends the Firefox webdriver to provide additional methods for inspecting requests."""
+    """Extend the Firefox webdriver to provide additional methods for inspecting requests."""
 
     def __init__(self, *args, seleniumwire_options=None, **kwargs):
         """Initialise a new Firefox WebDriver instance.
@@ -174,7 +179,7 @@ class Firefox(InspectRequestsMixin, DriverCommonMixin, _Firefox):
 
 
 class Chrome(InspectRequestsMixin, DriverCommonMixin, _Chrome):
-    """Extends the Chrome webdriver to provide additional methods for inspecting requests."""
+    """Extend the Chrome webdriver to provide additional methods for inspecting requests."""
 
     def __init__(self, *args, seleniumwire_options=None, **kwargs):
         """Initialise a new Chrome WebDriver instance.
@@ -200,14 +205,20 @@ class Chrome(InspectRequestsMixin, DriverCommonMixin, _Chrome):
         config = self._setup_backend(seleniumwire_options)
 
         if seleniumwire_options.get('auto_config', True):
-            for key, value in config.items():
-                chrome_options.set_capability(key, value)
+            try:
+                for key, value in config.items():
+                    chrome_options.set_capability(key, value)
+            except AttributeError:
+                # Earlier versions of the Chrome webdriver API require the
+                # DesiredCapabilities to be explicitly passed.
+                caps = kwargs.setdefault('desired_capabilities', DesiredCapabilities.CHROME.copy())
+                caps.update(config)
 
         super().__init__(*args, **kwargs)
 
 
 class Safari(InspectRequestsMixin, DriverCommonMixin, _Safari):
-    """Extends the Safari webdriver to provide additional methods for inspecting requests."""
+    """Extend the Safari webdriver to provide additional methods for inspecting requests."""
 
     def __init__(self, seleniumwire_options=None, *args, **kwargs):
         """Initialise a new Safari WebDriver instance.
@@ -230,7 +241,7 @@ class Safari(InspectRequestsMixin, DriverCommonMixin, _Safari):
 
 
 class Edge(InspectRequestsMixin, DriverCommonMixin, _Edge):
-    """Extends the Edge webdriver to provide additional methods for inspecting requests."""
+    """Extend the Edge webdriver to provide additional methods for inspecting requests."""
 
     def __init__(self, seleniumwire_options=None, *args, **kwargs):
         """Initialise a new Edge WebDriver instance.
@@ -253,7 +264,7 @@ class Edge(InspectRequestsMixin, DriverCommonMixin, _Edge):
 
 
 class Remote(InspectRequestsMixin, DriverCommonMixin, _Remote):
-    """Extends the Remote webdriver to provide additional methods for inspecting requests."""
+    """Extend the Remote webdriver to provide additional methods for inspecting requests."""
 
     def __init__(self, *args, seleniumwire_options=None, **kwargs):
         """Initialise a new Firefox WebDriver instance.
